<html>
<head>
    <!-- TODO: style log files list -->
    <style type="text/css">
        #logfile {
            border-collapse: collapse;
            font-family: "Lucida Sans Unicode","Lucida Grande",Sans-Serif;
            font-size: 13px;
            margin: 20px;
            text-align: left;
            width: 100%;
        }
        #logfile th {
            color: #003399;
            font-size: 14px;
            font-weight: normal;
            padding: 12px 15px;
        }
        #logfile td {
            border-top: 1px solid #E8EDFF;
            color: #666699;
            padding: 10px 15px;
        }
        #logfile tr:hover td {
            background: none repeat scroll 0 0 #EFF2FF;
            color: #333399;
        }
    </style>
</head>
<body>
{% block body %}
{% endblock %}
</body>
</html>