{% extends "base.html" %}
{% block body %}
{% if paginator.object_list %}
    <table id="logfile">
        {% if header_list %}
        <thead>
            <tr>
            {% for item in header_list %}
                <th>{{ item }}</th>
            {% endfor %}
            </tr>
        </thead>
        {% endif %}
        {% for line in paginator.object_list  %}
        <tr>
            {% for item in line %}
                {% for atom in item %}
                    <td>{{ atom }}</td>
                {% endfor %}
            {% endfor %}
        </tr>
        {% endfor %}
    </table>
{% endif %}
{% endblock %}