{% extends "admin/base_site.html" %}
{% load admin_static admin_list i18n %}
{% block extrastyle %}
    {{ block.super }}
    <link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}css/changelists.css" />
    {% if cl.formset %}
        <link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}css/forms.css" />
    {% endif %}
    {% if cl.formset or action_form %}
        {% url 'admin:jsi18n' as jsi18nurl %}
        <script type="text/javascript" src="{{ jsi18nurl|default:'../../jsi18n/' }}"></script>
    {% endif %}
    {{ media.css }}
    {% if not actions_on_top and not actions_on_bottom %}
        <style>
            #changelist table thead th:first-child {width: inherit}
        </style>
    {% endif %}
{% endblock %}

{% block extrahead %}
    {{ block.super }}
    {{ media.js }}
    {% if action_form %}{% if actions_on_top or actions_on_bottom %}
        <script type="text/javascript">
            (function($) {
                $(document).ready(function($) {
                    $("tr input.action-select").actions();
                });
            })(django.jQuery);
        </script>
    {% endif %}{% endif %}
{% endblock %}

{% block bodyclass %}change-list{% endblock %}

{% if not is_popup %}
    {% block breadcrumbs %}
        <div class="breadcrumbs">
            <a href="../../../">
                {% trans "Home" %}
            </a>
            &rsaquo;
            <a href="{% url "log-files-list-admin" %}">
                {% trans "Log files list" %}
            </a>
            &rsaquo;
            <a href="{% url "log-file-admin" file_id %}">
                {{ file_name }}
            </a>
            &rsaquo;
            <a href="{% url 'log-file-to-csv-admin' file_id %}">
                {{ file_name }} Download as CSV
            </a>
        </div>
    {% endblock %}
{% endif %}

{% block coltype %}flex{% endblock %}

{% block content %}
    <div id="content-main">
        {% block object-tools %}
            {% if has_add_permission %}
                <ul class="object-tools">
                    {% block object-tools-items %}
                        <li>
                            <a href="add/{% if is_popup %}?_popup=1{% endif %}" class="addlink">
                                {% blocktrans with cl.opts.verbose_name as name %}Add {{ name }}{% endblocktrans %}
                            </a>
                        </li>
                    {% endblock %}
                </ul>
            {% endif %}
        {% endblock %}
        {% if cl.formset.errors %}
            <p class="errornote">
                {% blocktrans count cl.formset.errors|length as counter %}Please correct the error below.{% plural %}Please correct the errors below.{% endblocktrans %}
            </p>
            {{ cl.formset.non_form_errors }}
        {% endif %}
        <div class="module{% if cl.has_filters %} filtered{% endif %}" id="changelist">
            {% comment %}
            {% block search %}{% search_form cl %}{% endblock %}
            {% block date_hierarchy %}{% date_hierarchy cl %}{% endblock %}
            {% endcomment %}

            {% block filters %}
                {% if cl.has_filters %}
                    <div id="changelist-filter">
                        <h2>{% trans 'Filter' %}</h2>
                        {% for spec in cl.filter_specs %}{% admin_list_filter cl spec %}{% endfor %}
                    </div>
                {% endif %}
            {% endblock %}

            <form id="changelist-form" action="" method="post"{% if cl.formset.is_multipart %} enctype="multipart/form-data"{% endif %}>{% csrf_token %}
                {% if cl.formset %}
                    <div>{{ cl.formset.management_form }}</div>
                {% endif %}

                {% block result_list %}
                    {% if action_form and actions_on_top and cl.full_result_count %}{% admin_actions %}{% endif %}

                    {% if paginator %}
                        {% block pagination %}
                        {% include 'logfile_paginator.html' %}
                        {% endblock %}
                    {% endif %}
                    {% if paginator.object_list %}
                    <div class="results">
                        <table id="result_list" cellspacing="0">
                            {% if header_list %}
                            <thead>
                            <tr>
                                {% for item in header_list %}
                                <th scope="col">{{ item }}</th>
                                {% endfor %}
                            </tr>
                            </thead>
                            {% endif %}
                            <tbody>
                            {% for line in paginator.object_list  %}
                            <tr class="row1">
                                {% for item in line %}
                                    {% for atom in item %}
                                        <td>{{ atom }}</td>
                                    {% endfor %}
                                {% endfor %}
                            </tr>
                            {% endfor %}
                            </tbody>
                        </table>
                    </div>
                    {% endif %}
                    {% if action_form and actions_on_bottom and cl.full_result_count %}{% admin_actions %}{% endif %}
                {% endblock %}
            </form>
        </div>
    </div>
{% endblock %}
